from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.presentation.common import *
from spire.presentation import *
from ctypes import *
import abc

class AnimationColorBehavior (  CommonBehavior) :
    """
    <summary>
        Represents a color effect for an animation behavior.
    </summary>
    """
    @property

    def From(self)->'ColorFormat':
        """
    <summary>
        Indicates the starting color of behavior.
            Read/write <see cref="T:Spire.Presentation.Drawing.ColorFormat" />.
    </summary>
        """
        GetDllLibPpt().AnimationColorBehavior_get_From.argtypes=[c_void_p]
        GetDllLibPpt().AnimationColorBehavior_get_From.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPpt().AnimationColorBehavior_get_From,self.Ptr)
        ret = None if intPtr==None else ColorFormat(intPtr)
        return ret


    @From.setter
    def From(self, value:'ColorFormat'):
        GetDllLibPpt().AnimationColorBehavior_set_From.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPpt().AnimationColorBehavior_set_From,self.Ptr, value.Ptr)

    @property

    def To(self)->'ColorFormat':
        """
    <summary>
        Indicates the ending color of behavior.
            Read/write <see cref="T:Spire.Presentation.Drawing.ColorFormat" />.
    </summary>
        """
        GetDllLibPpt().AnimationColorBehavior_get_To.argtypes=[c_void_p]
        GetDllLibPpt().AnimationColorBehavior_get_To.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPpt().AnimationColorBehavior_get_To,self.Ptr)
        ret = None if intPtr==None else ColorFormat(intPtr)
        return ret


    @To.setter
    def To(self, value:'ColorFormat'):
        GetDllLibPpt().AnimationColorBehavior_set_To.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPpt().AnimationColorBehavior_set_To,self.Ptr, value.Ptr)

    @property

    def By(self)->'AnimationColorTransform':
        """
    <summary>
        Describes the relative color value for the color animation.
            Read/write <see cref="T:Spire.Presentation.Drawing.ColorFormat" />.
    </summary>
        """
        GetDllLibPpt().AnimationColorBehavior_get_By.argtypes=[c_void_p]
        GetDllLibPpt().AnimationColorBehavior_get_By.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPpt().AnimationColorBehavior_get_By,self.Ptr)
        ret = None if intPtr==None else AnimationColorTransform(intPtr)
        return ret


    @By.setter
    def By(self, value:'AnimationColorTransform'):
        GetDllLibPpt().AnimationColorBehavior_set_By.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPpt().AnimationColorBehavior_set_By,self.Ptr, value.Ptr)

    @property

    def AnimationColorspace(self)->'AnimationColorspace':
        """
    <summary>
        Represent color space of behavior.
            Read/write <see cref="P:Spire.Presentation.Drawing.Animation.AnimationColorBehavior.AnimationColorspace" />.
    </summary>
        """
        GetDllLibPpt().AnimationColorBehavior_get_AnimationColorspace.argtypes=[c_void_p]
        GetDllLibPpt().AnimationColorBehavior_get_AnimationColorspace.restype=c_int
        ret = CallCFunction(GetDllLibPpt().AnimationColorBehavior_get_AnimationColorspace,self.Ptr)
        objwraped = AnimationColorspace(ret)
        return objwraped

    @AnimationColorspace.setter
    def AnimationColorspace(self, value:'AnimationColorspace'):
        GetDllLibPpt().AnimationColorBehavior_set_AnimationColorspace.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPpt().AnimationColorBehavior_set_AnimationColorspace,self.Ptr, value.value)

    @property

    def Direction(self)->'AnimationColorDirection':
        """
    <summary>
        Indicates that direction to cycle the hue around the color wheel.
            Read/write <see cref="T:Spire.Presentation.Drawing.Animation.AnimationColorDirection" />.
    </summary>
        """
        GetDllLibPpt().AnimationColorBehavior_get_Direction.argtypes=[c_void_p]
        GetDllLibPpt().AnimationColorBehavior_get_Direction.restype=c_int
        ret = CallCFunction(GetDllLibPpt().AnimationColorBehavior_get_Direction,self.Ptr)
        objwraped = AnimationColorDirection(ret)
        return objwraped

    @Direction.setter
    def Direction(self, value:'AnimationColorDirection'):
        GetDllLibPpt().AnimationColorBehavior_set_Direction.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPpt().AnimationColorBehavior_set_Direction,self.Ptr, value.value)

