from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.presentation.common import *
from spire.presentation import *
from ctypes import *
import abc

class SlideSize (SpireObject) :
    """
    <summary>
        Represents a size of slide.
    </summary>
    """
    @property

    def Size(self)->'SizeF':
        """
    <summary>
        Gets or sets the size in points.
            Read/Write <see cref="T:System.Drawing.SizeF" />.
    </summary>
        """
        GetDllLibPpt().SlideSize_get_Size.argtypes=[c_void_p]
        GetDllLibPpt().SlideSize_get_Size.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPpt().SlideSize_get_Size,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @Size.setter
    def Size(self, value:'SizeF'):
        GetDllLibPpt().SlideSize_set_Size.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPpt().SlideSize_set_Size,self.Ptr, value.Ptr)

    @property

    def SizeOfPx(self)->'SizeF':
        """
    <summary>
        Gets or sets the size in pixel.
            Read/Write <see cref="T:System.Drawing.SizeF" />.
    </summary>
        """
        GetDllLibPpt().SlideSize_get_SizeOfPx.argtypes=[c_void_p]
        GetDllLibPpt().SlideSize_get_SizeOfPx.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPpt().SlideSize_get_SizeOfPx,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @SizeOfPx.setter
    def SizeOfPx(self, value:'SizeF'):
        GetDllLibPpt().SlideSize_set_SizeOfPx.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPpt().SlideSize_set_SizeOfPx,self.Ptr, value.Ptr)

    @property

    def Type(self)->'SlideSizeType':
        """
    <summary>
        Gets or sets the type of slide size.
            Read/Write <see cref="T:Spire.Presentation.SlideSizeType" />.
    </summary>
        """
        GetDllLibPpt().SlideSize_get_Type.argtypes=[c_void_p]
        GetDllLibPpt().SlideSize_get_Type.restype=c_int
        ret = CallCFunction(GetDllLibPpt().SlideSize_get_Type,self.Ptr)
        objwraped = SlideSizeType(ret)
        return objwraped

    @Type.setter
    def Type(self, value:'SlideSizeType'):
        GetDllLibPpt().SlideSize_set_Type.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPpt().SlideSize_set_Type,self.Ptr, value.value)

    @property

    def Orientation(self)->'SlideOrienation':
        """
    <summary>
        Gets or sets the slide orientation.
            Read/Write <see cref="T:Spire.Presentation.SlideOrienation" />.
    </summary>
        """
        GetDllLibPpt().SlideSize_get_Orientation.argtypes=[c_void_p]
        GetDllLibPpt().SlideSize_get_Orientation.restype=c_int
        ret = CallCFunction(GetDllLibPpt().SlideSize_get_Orientation,self.Ptr)
        objwraped = SlideOrienation(ret)
        return objwraped

    @Orientation.setter
    def Orientation(self, value:'SlideOrienation'):
        GetDllLibPpt().SlideSize_set_Orientation.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPpt().SlideSize_set_Orientation,self.Ptr, value.value)

